# Automations Best Practices: Automations with Webhooks
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#overview)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#best-practices)
  * [Sending Notifications on Quality State Changes](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#sending-notifications-on-quality-state-changes)
  * [Initiating a Survey Run when a Tag is Added](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#initiating-a-survey-run-when-a-tag-is-added)
  * [Initiating Calculations on Lifecycle Phase Changes](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#initiating-calculations-on-lifecycle-phase-changes)
  * [Initiating Calculations on Field Changes](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks#initiating-calculations-on-field-changes)


Explore best practices and examples for setting up automations that send webhooks to a target URL.
